coviolations.io app
===================

`See docs on read the docs <https://coviolationsio.readthedocs.org/en/latest/>`_

Installation
-------------

For installing use:

.. code-block:: bash

    pip install coviolations_app
